<?php

namespace Enwikuna\Enwikuna_Helper\Admin;

defined( 'ABSPATH' ) || exit;

use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Singleton_Abstract;
use Enwikuna\Enwikuna_Helper\Admin\Interfaces\Enwikuna_Helper_Admin_Menus_Interface;
use Enwikuna\Enwikuna_Helper\Enwikuna_Helper_Install;

/**
 * Class Enwikuna_Helper_Admin_Menus
 *
 * @package Enwikuna\Enwikuna_Helper\Admin
 */
class Enwikuna_Helper_Admin_Menus extends Enwikuna_Helper_Singleton_Abstract implements Enwikuna_Helper_Admin_Menus_Interface {

	/**
	 * Enwikuna_Helper_Admin_Menus constructor
	 */
	public function __construct() {
		if ( is_admin() ) {
			$this->init_hooks();
		}
	}

	/**
	 * Init / set up hooks
	 */
	private function init_hooks(): void {
		add_action( 'admin_menu', array( $this, 'admin_menu_action' ) );
	}

	/**
	 * Introduce Enwikuna Helper admin menu
	 */
	public function admin_menu_action(): void {
		$plugin_base_slug = 'enwikuna';

		add_dashboard_page(
			esc_html__( 'Enwikuna', 'enwikuna-helper' ),
			esc_html__( 'Enwikuna', 'enwikuna-helper' ),
			'administrator',
			$plugin_base_slug,
			array(
				$this,
				'dashboard_page',
			)
		);

		add_management_page(
			esc_html__( 'Enwikuna Support', 'enwikuna-helper' ),
			esc_html__( 'Enwikuna Support', 'enwikuna-helper' ),
			'administrator',
			'enwikuna-support',
			array(
				$this,
				'support_page',
			)
		);
	}

	/**
	 * Output the dashboard page
	 */
	public function dashboard_page(): void {
		Enwikuna_Helper_Admin_Dashboard::get_instance()->output();
	}

	/**
	 * Output the support page
	 */
	public function support_page(): void {
		Enwikuna_Helper_Install::get_instance()->verify_db_tables( true );
		Enwikuna_Helper_Admin_Support::get_instance()->output();
	}
}
