<?php

namespace Enwikuna\Enwikuna_Helper\Admin;

defined( 'ABSPATH' ) || exit;

use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Singleton_Abstract;
use Enwikuna\Enwikuna_Helper\Admin\Interfaces\Enwikuna_Helper_Admin_Page_Actions_Interface;

/**
 * Class Enwikuna_Helper_Admin_Page_Actions
 *
 * @package Enwikuna\Enwikuna_Helper\Admin
 */
class Enwikuna_Helper_Admin_Page_Actions extends Enwikuna_Helper_Singleton_Abstract implements Enwikuna_Helper_Admin_Page_Actions_Interface {

	/**
	 * Enwikuna_Helper_Admin_Page_Actions constructor
	 */
	public function __construct() {
		if ( is_admin() ) {
			$this->init_hooks();
		}
	}

	/**
	 * Init / set up hooks
	 */
	private function init_hooks(): void {
		add_action( 'admin_init', array( $this, 'admin_init_action' ), 999 );
	}

	/**
	 * Handle admin pages load and process actions
	 */
	public function admin_init_action(): void {
		global $current_tab;

		if ( $this->is_ewkh_admin_page() && ! wp_doing_ajax() ) {
			$page = str_replace( 'enwikuna-', '', ewkh_clean( wp_unslash( $_GET['page'] ?? '' ) ) ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended

			/**
			 * This filter filters the admin page tabs array
			 *
			 * @param array $page_tabs_array Includes the page tabs array
			 *
			 * @wp-hook ewkh_admin_{page}_tabs_array
			 * @since 2.0.0
			 */
			$page_tabs_array = apply_filters( 'ewkh_admin_' . $page . '_tabs_array', array() );

			/**
			 * This hook fires before an admin page action
			 *
			 * @wp-hook ewkh_admin_before_page_action_{page}
			 * @since 1.7.0
			 */
			do_action( 'ewkh_admin_before_page_action_' . $page );

			// Set current tab in case its a page with tabbing
			if ( ! empty( $page_tabs_array ) ) {
				$current_tab = ewkh_get_current_tab( array_key_first( $page_tabs_array ) );
			}

			/**
			 * This hook fires the admin page action
			 *
			 * @wp-hook ewkh_admin_page_action_{page}
			 * @since 1.7.0
			 */
			do_action( 'ewkh_admin_page_action_' . $page );

			/**
			 * This hook fires after an admin page action
			 *
			 * @wp-hook ewkh_admin_after_page_action_{page}
			 * @since 1.7.0
			 */
			do_action( 'ewkh_admin_after_page_action_' . $page );
		}
	}

	/**
	 * Checks if the current page is a Enwikuna Helper page
	 *
	 * @return bool
	 */
	private function is_ewkh_admin_page(): bool {
		$is_ewkh_page = false;

		if ( isset( $_GET['page'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
			$page = ewkh_clean( wp_unslash( $_GET['page'] ) ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended

			if ( ! empty( $page ) && false !== strpos( $page, 'enwikuna' ) ) {
				$is_ewkh_page = true;
			}
		}

		return $is_ewkh_page;
	}
}
