<?php

namespace Enwikuna\Enwikuna_Helper\Admin;

defined( 'ABSPATH' ) || exit;

use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Singleton_Abstract;
use Enwikuna\Enwikuna_Helper\Admin\Interfaces\Enwikuna_Helper_Admin_Support_Interface;
use Enwikuna\Enwikuna_Helper\Admin\Support\Modules\Enwikuna_Helper_Admin_Support_Debugger;
use Enwikuna\Enwikuna_Helper\Admin\Support\Modules\Enwikuna_Helper_Admin_Support_Function_Executer;
use Enwikuna\Enwikuna_Helper\Admin\Support\Modules\Enwikuna_Helper_Admin_Support_Service_User;

/**
 * Class Enwikuna_Helper_Admin_Support
 *
 * @package Enwikuna\Enwikuna_Helper\Admin
 */
class Enwikuna_Helper_Admin_Support extends Enwikuna_Helper_Singleton_Abstract implements Enwikuna_Helper_Admin_Support_Interface {

	/**
	 * Enwikuna_Helper_Admin_Support constructor
	 */
	public function __construct() {
		if ( is_admin() ) {
			$this->init_hooks();
		}
	}

	/**
	 * Init / set up hooks
	 */
	private function init_hooks(): void {
		add_action( 'ewkh_admin_page_action_support', array( $this, 'ewkh_admin_page_action_support_action' ) );
		add_action( 'init', array( $this, 'init_action' ) );
	}

	/**
	 * Init the support
	 */
	public function init_action(): void {
		Enwikuna_Helper_Admin_Support_Service_User::get_instance();
		Enwikuna_Helper_Admin_Support_Debugger::get_instance();
		Enwikuna_Helper_Admin_Support_Function_Executer::get_instance();
	}

	/**
	 * Output the support page
	 */
	public function output(): void {
		Enwikuna_Helper_Admin_Templates::get_instance()->get_admin_page( 'support' );
	}

	/**
	 * Support actions
	 */
	public function ewkh_admin_page_action_support_action(): void {
		if ( ewkh_is_action( 'enable-service-user' ) ) {
			Enwikuna_Helper_Admin_Support_Service_User::get_instance()->enable_service_user();
		}

		if ( ewkh_is_action( 'disable-service-user' ) ) {
			Enwikuna_Helper_Admin_Support_Service_User::get_instance()->disable_service_user( true );
		}

		if ( ewkh_is_action( 'enable-debug-logging' ) ) {
			Enwikuna_Helper_Admin_Support_Debugger::get_instance()->enable_debugging();
		}

		if ( ewkh_is_action( 'disable-debug-logging' ) ) {
			Enwikuna_Helper_Admin_Support_Debugger::get_instance()->disable_debugging();
		}

		if ( ewkh_is_action( 'delete-debug-log' ) ) {
			Enwikuna_Helper_Admin_Support_Debugger::get_instance()->delete_debug_log();
		}

		if ( ewkh_is_action( 'execute-function' ) ) {
			Enwikuna_Helper_Admin_Support_Function_Executer::get_instance()->execute_function();
		}
	}

	/**
	 * Outputs a page
	 *
	 * @param string $page
	 */
	public function output_page( string $page ): void {
		if ( ! empty( $page ) ) {
			Enwikuna_Helper_Admin_Templates::get_instance()->get_admin_support_page( $page );
		}
	}
}
