<?php

namespace Enwikuna\Enwikuna_Helper\Admin;

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Singleton_Abstract;
use Enwikuna\Enwikuna_Helper\Admin\Interfaces\Enwikuna_Helper_Admin_Templates_Interface;

/**
 * Class Enwikuna_Helper_Admin_Templates
 *
 * @package Enwikuna\Enwikuna_Helper\Admin
 */
class Enwikuna_Helper_Admin_Templates extends Enwikuna_Helper_Singleton_Abstract implements Enwikuna_Helper_Admin_Templates_Interface {

	/**
	 * The file path to the admin pages dir
	 *
	 * @var string
	 */
	private string $admin_pages_dir;

	/**
	 * The file path to the admin setup wizard dir
	 *
	 * @var string
	 */
	private string $admin_setup_wizard_dir;

	/**
	 * The file path to the admin support pages dir
	 *
	 * @var string
	 */
	private string $admin_support_pages_dir;

	/**
	 * Enwikuna_Helper_Admin_Templates constructor
	 */
	public function __construct() {
		$this->admin_pages_dir         = Constants::get_constant( 'ENWIKUNA_HELPER_ADMIN_TEMPLATES_DIR' ) . 'pages' . DIRECTORY_SEPARATOR;
		$this->admin_setup_wizard_dir  = Constants::get_constant( 'ENWIKUNA_HELPER_ADMIN_TEMPLATES_DIR' ) . 'setup-wizard' . DIRECTORY_SEPARATOR;
		$this->admin_support_pages_dir = $this->admin_pages_dir . 'support' . DIRECTORY_SEPARATOR;
	}

	/**
	 * Get an admin page
	 *
	 * @param string $page
	 * @param array $args
	 */
	public function get_admin_page( string $page, array $args = array() ): void {
		$admin_page   = $this->admin_pages_dir . $page . '.php';
		$admin_footer = Constants::get_constant( 'ENWIKUNA_HELPER_ADMIN_TEMPLATES_DIR' ) . 'footer.php';

		ewkh_get_template( $admin_page, $args );
		ewkh_get_template( $admin_footer, $args );
	}

	/**
	 * Get the admin setup wizard
	 *
	 * @param array $args
	 */
	public function get_admin_setup_wizard( array $args = array() ): void {
		$admin_setup_wizard = $this->admin_setup_wizard_dir . 'setup-wizard.php';

		ewkh_get_template( $admin_setup_wizard, $args );
	}

	/**
	 * Get an admin setup wizard view
	 *
	 * @param string $view
	 * @param array $args
	 */
	public function get_admin_setup_wizard_view( string $view, array $args = array() ): void {
		$admin_setup_wizard_view = $this->admin_setup_wizard_dir . 'views' . DIRECTORY_SEPARATOR . $view . '.php';

		ewkh_get_template( $admin_setup_wizard_view, $args );
	}

	/**
	 * Get an admin support page
	 *
	 * @param string $page
	 * @param array $args
	 */
	public function get_admin_support_page( string $page, array $args = array() ): void {
		$status_page = $this->admin_support_pages_dir . $page . '.php';

		ewkh_get_template( $status_page, $args );
	}
}
