<?php

namespace Enwikuna\Enwikuna_Helper\Admin\Interfaces;

defined( 'ABSPATH' ) || exit;

/**
 * Interface Enwikuna_Helper_Admin_Setup_Wizard_Interface
 *
 * @package Enwikuna\Enwikuna_Helper\Admin\Interfaces
 */
interface Enwikuna_Helper_Admin_Setup_Wizard_Interface {

	/**
	 * Enwikuna_Helper_Admin_Setup_Wizard constructor
	 */
	public function __construct();

	/**
	 * Introduce Enwikuna Helper setup wizard page
	 */
	public function admin_menu_action(): void;

	/**
	 * Initialize & show the setup wizard
	 */
	public function admin_init_action(): void;

	/**
	 * Register admin setup wizard styles
	 */
	public function admin_enqueue_styles_action(): void;

	/**
	 * Returns the current setup wizard step key
	 *
	 * @return string
	 */
	public function get_current_step_key(): string;

	/**
	 * Returns the current setup wizard step index
	 *
	 * @return int
	 */
	public function get_current_step_index(): int;

	/**
	 * Returns the setup wizard step index
	 *
	 * @param string $step_key
	 *
	 * @return int
	 */
	public function get_step_index( string $step_key ): int;

	/**
	 * Returns all steps of the setup wizard
	 *
	 * @return array
	 */
	public function get_steps(): array;

	/**
	 * Returns the URL of a step
	 *
	 * @param string $step_key
	 *
	 * @return string
	 */
	public function get_step_url( string $step_key ): string;

	/**
	 * Returns a step from the steps array
	 *
	 * @param string $step_key
	 *
	 * @return array|false
	 */
	public function get_step( string $step_key = '' );

	/**
	 * Returns the next step key in the wizard
	 *
	 * @return int|string
	 */
	public function get_next_step_key();

	/**
	 * Returns the error messages for the setup wizard
	 *
	 * @param string $step_key
	 *
	 * @return false|mixed
	 */
	public function get_error_message( string $step_key = '' );

	/**
	 * Returns the content of each step by using it's helper function
	 *
	 * @param string $view
	 */
	public function get_step_content( string $view ): void;

	/**
	 * Save action of the wizard when pressing the next button
	 */
	public function admin_post_ewkh_admin_setup_wizard_action(): void;

	/**
	 * Returns the setup wizard welcome view
	 */
	public function view_welcome(): void;

	/**
	 * Handles the submit button click actions of the setup wizard welcome view
	 */
	public function view_welcome_handler(): void;

	/**
	 * Returns the setup wizard encryptor view
	 */
	public function view_encryptor(): void;

	/**
	 * Handles the submit button click actions of the setup wizard encryptor view
	 */
	public function view_encryptor_handler(): void;

	/**
	 * Returns the setup wizard first steps view
	 */
	public function view_first_steps(): void;

	/**
	 * Returns the items for the first steps list
	 *
	 * @return array
	 */
	public function get_first_steps_list(): array;
}
