<?php

namespace Enwikuna\Enwikuna_Helper\Admin\Support;

defined( 'ABSPATH' ) || exit;

use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Singleton_Abstract;
use Enwikuna\Enwikuna_Helper\Admin\Enwikuna_Helper_Admin_Support;
use Enwikuna\Enwikuna_Helper\Admin\Support\Interfaces\Enwikuna_Helper_Admin_Support_Page_Interface;

/**
 * Class Enwikuna_Helper_Admin_Support_Page
 *
 * @package Enwikuna\Enwikuna_Helper\Admin\Support
 */
class Enwikuna_Helper_Admin_Support_Page extends Enwikuna_Helper_Singleton_Abstract implements Enwikuna_Helper_Admin_Support_Page_Interface {

	/**
	 * Page id
	 *
	 * @var string
	 */
	protected string $id = '';

	/**
	 * Page label
	 *
	 * @var string
	 */
	protected string $label = '';

	/**
	 * Enwikuna_Helper_Admin_Support_Page constructor
	 */
	public function __construct() {
		if ( is_admin() ) {
			$this->init_hooks();
		}
	}

	/**
	 * Init / set up hooks
	 */
	private function init_hooks(): void {
		add_filter( 'ewkh_admin_support_tabs_array', array( $this, 'filter_ewkh_admin_support_tabs_array' ), 20 );
		add_action( 'ewkh_admin_support_' . $this->id, array( $this, 'ewkh_admin_support_output_action' ) );
	}

	/**
	 * Get page id
	 *
	 * @return string
	 */
	public function get_id(): string {
		return $this->id;
	}

	/**
	 * Get page label
	 *
	 * @return string
	 */
	public function get_label(): string {
		return $this->label;
	}

	/**
	 * Add this page to the support tabs array
	 *
	 * @param array $pages
	 *
	 * @return array
	 */
	public function filter_ewkh_admin_support_tabs_array( array $pages ): array {
		$pages[ $this->id ] = $this->label;

		return $pages;
	}

	/**
	 * Get page
	 *
	 * @return string
	 */
	public function get_page(): string {
		/**
		 * This filter filters the current admin support page ID
		 *
		 * @param string $id The page ID
		 *
		 * @wp-hook ewkh_admin_get_support_page_{id}
		 * @since 2.0.0
		 */
		return apply_filters( 'ewkh_admin_get_support_page_' . $this->id, $this->id );
	}

	/**
	 * Output page
	 */
	public function ewkh_admin_support_output_action(): void {
		$page = $this->get_page();

		Enwikuna_Helper_Admin_Support::get_instance()->output_page( $page );
	}
}
