<?php

namespace Enwikuna\Enwikuna_Helper\Admin\Support\Modules;

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Enwikuna\Enwikuna_Helper\Admin\Enwikuna_Helper_Admin_Notices;
use Enwikuna\Enwikuna_Helper\Admin\Support\Enwikuna_Helper_Admin_Support_Page;
use Enwikuna\Enwikuna_Helper\Admin\Support\Modules\Interfaces\Enwikuna_Helper_Admin_Support_Function_Executer_Interface;

/**
 * Class Enwikuna_Helper_Admin_Support_Function_Executer
 *
 * @package Enwikuna\Enwikuna_Helper\Admin\Support\Modules
 */
class Enwikuna_Helper_Admin_Support_Function_Executer extends Enwikuna_Helper_Admin_Support_Page implements Enwikuna_Helper_Admin_Support_Function_Executer_Interface {

	/**
	 * Additional files which are registered within each plugin
	 *
	 * @var array
	 */
	private array $additional_files;

	/**
	 * Enwikuna_Helper_Admin_Support_Function_Executer constructor
	 */
	public function __construct() {
		if ( is_admin() ) {
			$this->id    = 'function-executer';
			$this->label = esc_html__( 'Function executer', 'enwikuna-helper' );

			$this->additional_files[] = Constants::get_constant( 'ENWIKUNA_HELPER_ABSPATH' ) . 'includes' . DIRECTORY_SEPARATOR . 'functions' . DIRECTORY_SEPARATOR . 'enwikuna-helper-update-functions.php';

			/**
			 * This filter filters the admin support function executer files
			 *
			 * @param array $additional_files Includes all function executer additional files
			 *
			 * @wp-hook ewkh_admin_support_function_executer_add_files
			 * @since 2.0.0
			 */
			$this->additional_files = apply_filters( 'ewkh_admin_support_function_executer_add_files', $this->additional_files );

			parent::__construct();
		}
	}

	/**
	 * Get support
	 *
	 * @return string
	 */
	public function get_support(): string {
		/**
		 * This filter filters the current admin support ID
		 *
		 * @param string $id The support ID
		 *
		 * @wp-hook ewkh_admin_get_support_{id}
		 * @since 2.0.0
		 */
		return apply_filters( 'ewkh_admin_get_support_' . $this->id, $this->id );
	}

	/**
	 * Executes the needed function
	 */
	public function execute_function(): void {
		check_admin_referer( 'enwikuna-helper-execute-function', 'enwikuna-helper-execute-function-nonce' );

		$function = ewkh_clean( wp_unslash( $_POST['function'] ?? null ) );

		if ( ! empty( $this->additional_files ) ) {
			foreach ( $this->additional_files as $additional_file ) {
				include_once $additional_file;
			}
		}

		if ( ! empty( $function ) && function_exists( $function ) && is_callable( $function ) ) {
			$function();

			Enwikuna_Helper_Admin_Notices::get_instance()->success( wp_kses_post( sprintf( __( 'The function <strong>%s</strong> was executed successfully.', 'enwikuna-helper' ), $function ) ) );
		} else {
			Enwikuna_Helper_Admin_Notices::get_instance()->error( wp_kses_post( sprintf( __( 'An error occurred while trying to execute the function <strong>%s</strong>.', 'enwikuna-helper' ), $function ) ) );
		}

		wp_safe_redirect( admin_url( 'tools.php?page=enwikuna-support&tab=function-executer' ) );
		exit;
	}
}
