<?php

namespace Enwikuna\Enwikuna_Helper;

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Singleton_Abstract;
use Enwikuna\Enwikuna_Helper\Interfaces\Enwikuna_Helper_Dependencies_Interface;

/**
 * Class Enwikuna_Helper_Dependencies
 *
 * @package Enwikuna\Enwikuna_Helper
 */
class Enwikuna_Helper_Dependencies extends Enwikuna_Helper_Singleton_Abstract implements Enwikuna_Helper_Dependencies_Interface {

	/**
	 * Whether the plugin is loadable or not
	 *
	 * @var bool
	 */
	private bool $loadable = true;

	/**
	 * Enwikuna_Helper_Dependencies constructor
	 */
	public function __construct() {
		$required_constants = array(
			'ENWIKUNA_HELPER_REST_API_URL',
			'ENWIKUNA_HELPER_REST_API_KEY',
			'ENWIKUNA_HELPER_REST_API_SECRET',
			'ENWIKUNA_HELPER_PRODUCT_UUID',
			'ENWIKUNA_HELPER_TRUSTED_SIGNING_KEY',
		);

		foreach ( $required_constants as $constant ) {
			if ( empty( Constants::get_constant( $constant ) ) ) {
				$this->loadable = false;

				break;
			}
		}
	}

	/**
	 * Return if the plugin is loadable or not
	 *
	 * @return bool
	 */
	public function is_loadable(): bool {
		/**
		 * This filter filters if the plugin is loadable
		 *
		 * @param bool $loadable If is loadable or not
		 *
		 * @wp-hook ewkh_dependencies_is_loadable
		 * @since 2.3.0
		 */
		return apply_filters( 'ewkh_dependencies_is_loadable', $this->loadable );
	}
}
