<?php

namespace Enwikuna\Enwikuna_Helper;

defined( 'ABSPATH' ) || exit;

use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Product_Abstract;
use Enwikuna\Enwikuna_Helper\Interfaces\Enwikuna_Helper_Plugin_Interface;
use Enwikuna_Helper_Product_Type_Abstract;

/**
 * Class Enwikuna_Helper_Plugin
 *
 * @package Enwikuna\Enwikuna_Helper
 */
class Enwikuna_Helper_Plugin extends Enwikuna_Helper_Product_Abstract implements Enwikuna_Helper_Plugin_Interface {

	/**
	 * Enwikuna_Helper_Plugin constructor
	 *
	 * @param string $file
	 * @param string $product_id
	 * @param array $args
	 */
	public function __construct( string $file, string $product_id, array $args = array() ) {
		$this->set_type();
		$this->set_product_meta( $file );

		parent::__construct( $file, $product_id, $args );
	}

	/**
	 * Sets the product type
	 *
	 * @return void
	 */
	public function set_type(): void {
		$this->type = Enwikuna_Helper_Product_Type_Abstract::PLUGIN;
	}

	/**
	 * Sets the product meta
	 *
	 * @param string $file
	 *
	 * @return void
	 */
	public function set_product_meta( string $file ): void {
		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		if ( function_exists( 'get_plugin_data' ) && function_exists( '_get_plugin_data_markup_translate' ) ) {
			$plugin_data        = get_plugin_data( WP_PLUGIN_DIR . '/' . $file );
			$this->product_meta = _get_plugin_data_markup_translate( $file, $plugin_data, false );
		}
	}

	/**
	 * Returns the product value
	 *
	 * @param string $meta_key
	 *
	 * @return string
	 */
	protected function get_meta_value( string $meta_key ): string {
		if ( 'URI' === $meta_key ) {
			$meta_key = 'Plugin' . $meta_key;
		}

		return $this->product_meta[ $meta_key ] ?? '';
	}
}
