<?php

namespace Enwikuna\Enwikuna_Helper;

defined( 'ABSPATH' ) || exit;

use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Singleton_Abstract;
use Enwikuna\Enwikuna_Helper\Data_Stores\Enwikuna_Helper_Data_Store_Support;
use Enwikuna\Enwikuna_Helper\Data_Stores\Models\Enwikuna_Helper_Data_Store_Service_User_Model;
use Enwikuna\Enwikuna_Helper\Interfaces\Enwikuna_Helper_Service_User_Interface;

/**
 * Class Enwikuna_Helper_Service_User
 *
 * @package Enwikuna\Enwikuna_Helper
 */
class Enwikuna_Helper_Service_User extends Enwikuna_Helper_Singleton_Abstract implements Enwikuna_Helper_Service_User_Interface {

	/**
	 * Creates a new service user in the database
	 *
	 * @param array $service_user_data
	 *
	 * @return false|Enwikuna_Helper_Data_Store_Service_User_Model
	 */
	public function create( array $service_user_data ) {
		if ( empty( $service_user_data ) ) {
			return false;
		}

		/**
		 * @var Enwikuna_Helper_Data_Store_Service_User_Model $service_user
		 */
		$service_user = Enwikuna_Helper_Data_Store_Support::get_instance()->insert( $service_user_data );

		if ( ! $service_user ) {
			return false;
		}

		return $service_user;
	}

	/**
	 * Find the first service user in the database
	 *
	 * @return Enwikuna_Helper_Data_Store_Service_User_Model|false
	 */
	public function find() {
		/**
		 * @var Enwikuna_Helper_Data_Store_Service_User_Model $service_user
		 */
		$service_user = Enwikuna_Helper_Data_Store_Support::get_instance()->find_all( null, 1 );

		if ( ! $service_user ) {
			return false;
		}

		return $service_user[0];
	}

	/**
	 * Deletes a service user from the database
	 *
	 * @param array $where
	 *
	 * @return bool
	 */
	public function delete_by( array $where ): bool {
		if ( empty( $where ) ) {
			return false;
		}

		return Enwikuna_Helper_Data_Store_Support::get_instance()->delete_by( $where );
	}
}
