<?php

namespace Enwikuna\Enwikuna_Helper;

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Enwikuna\Enwikuna_Helper\Admin\Enwikuna_Helper_Admin_Notices;
use Enwikuna\Enwikuna_Helper\Interfaces\Enwikuna_Helper_Uninstall_Interface;

/**
 * Class Enwikuna_Helper_Uninstall
 *
 * @package Enwikuna\Enwikuna_Helper
 */
class Enwikuna_Helper_Uninstall implements Enwikuna_Helper_Uninstall_Interface {

	/**
	 * Deactivate Enwikuna Helper
	 */
	public static function deactivate(): void {
		self::clear_scheduled_hooks();
		self::remove_admin_notices();
	}

	/**
	 * Uninstall Enwikuna Helper
	 */
	public static function uninstall(): void {
		global $wpdb; //DB

		self::clear_scheduled_hooks();
		self::remove_admin_notices();

		// Only remove ALL plugin data if ENWIKUNA_HELPER_REMOVE_ALL_DATA constant is set to true in the wp-config.php
		if ( Constants::get_constant( 'ENWIKUNA_HELPER_REMOVE_ALL_DATA' ) ) {
			// Delete tables
			self::drop_tables();

			// Delete encryptor key from wp-config.php
			Enwikuna_Helper_Encryptor::get_instance()->auto_delete_key();

			// Delete options
			$options_table        = $wpdb->options;
			$delete_options_query = $wpdb->prepare( "DELETE FROM $options_table WHERE option_name LIKE %s;", 'ewkh\_%' ); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared

			$wpdb->query( $delete_options_query ); // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared

			// Delete usermeta
			$usermeta_table        = $wpdb->usermeta;
			$delete_usermeta_query = $wpdb->prepare( "DELETE FROM $usermeta_table WHERE meta_key LIKE %s;", 'ewkh\_%' ); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared

			$wpdb->query( $delete_usermeta_query ); // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared

			wp_cache_flush();
		}
	}

	/**
	 * Clears all scheduled hooks
	 */
	public static function clear_scheduled_hooks(): void {
		$cron_hooks = Enwikuna_Helper_Cron_Jobs::get_instance()->get_cron_hooks();

		foreach ( $cron_hooks as $cron_hook ) {
			Enwikuna_Helper_Cron_Jobs::get_instance()->clear( $cron_hook );
		}
	}

	/**
	 * Remove all admin notices
	 *
	 * @return void
	 */
	public static function remove_admin_notices(): void {
		Enwikuna_Helper_Admin_Notices::get_instance()->remove_all_admin_notices();
	}

	/**
	 * Drop Enwikuna Helper tables
	 */
	private static function drop_tables(): void {
		global $wpdb; //DB

		$tables = Enwikuna_Helper_Install::get_instance()->get_ewkh_tables();

		foreach ( $tables as $table ) {
			$wpdb->query( "DROP TABLE IF EXISTS $table" ); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		}
	}
}
