<?php

use Enwikuna\Enwikuna_Helper\Enwikuna_Helper;
use Enwikuna\Enwikuna_Helper\Enwikuna_Helper_Cron_Jobs;
use Enwikuna\Enwikuna_Helper\Enwikuna_Helper_Encryptor;

defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'ewkh_update_120_encryptor_setup' ) ) {
	/**
	 * Setup encryptor in case its not already setup by install
	 */
	function ewkh_update_120_encryptor_setup() {
		Enwikuna_Helper_Encryptor::get_instance()->auto_insert_key();
	}
}

if ( ! function_exists( 'ewkh_update_120_re_encrypt_data' ) ) {
	/**
	 * Re encrypt data e.g. license keys with Encryptor
	 */
	function ewkh_update_120_re_encrypt_data() {
		if ( ! Enwikuna_Helper_Encryptor::get_instance()->is_configured() ) {
			Enwikuna_Helper_Cron_Jobs::get_instance()->schedule_single(
				time() + 60 * 60,
				'enwikuna_helper_update_callback',
				false,
				array(
					'update_callback' => 'ewkh_update_120_re_encrypt_data',
				)
			);

			return;
		}

		$products = Enwikuna_Helper::get_instance()->get_products( false );

		if ( ! empty( $products ) ) {
			$registered_products = Enwikuna_Helper::get_instance()->get_registered_products();

			foreach ( $products as $file => $product ) {
				$license_key = $product->get_license_key();

				// License key is still encrypted via old method and needs to be converted
				if ( ! empty( $license_key ) && 60 === strlen( $license_key ) ) {
					$secret_key = 'QrM6o40corOmqJjJVrWC7HGgk6Rukc2u';
					$secret_iv  = '4nYPHxXx3Ol72K3crpfKqt6FYvakWe3M';
					$hashed_key = hash( 'sha256', $secret_key );
					$iv         = mb_substr( hash( 'sha256', $secret_iv ), 0, 16 );

					$decrypted_license_key = openssl_decrypt( base64_decode( $license_key ), 'AES-256-CBC', $hashed_key, 0, $iv ); // phpcs:ignore WordPress.PHP.DiscouragedPHPFunctions.obfuscation_base64_decode

					// Successfully decrypted license key with old method > encrypt with new one
					if ( ! empty( $decrypted_license_key ) && 19 === strlen( $decrypted_license_key ) ) {
						$registered_products[ $file ]['license_key'] = Enwikuna_Helper_Encryptor::get_instance()->maybe_encrypt( $decrypted_license_key );
					}
				}
			}

			Enwikuna_Helper::get_instance()->update_registered_products( $registered_products );
		}
	}
}

if ( ! function_exists( 'ewkh_update_220_set_host_url' ) ) {
	/**
	 * Set host URL for all registered products
	 */
	function ewkh_update_220_set_host_url() {
		$registered_products = Enwikuna_Helper::get_instance()->get_registered_products();

		if ( ! empty( $registered_products ) ) {
			foreach ( $registered_products as $file => $product ) {
				$registered_products[ $file ]['host'] = ewkh_prepare_license_host_url( home_url() );
			}

			Enwikuna_Helper::get_instance()->update_registered_products( $registered_products );
		}
	}
}
