<?php

namespace Enwikuna\Enwikuna_Helper\Gateways\Interfaces;

defined( 'ABSPATH' ) || exit;

use Enwikuna\Enwikuna_Helper\Abstracts\Enwikuna_Helper_Product_Abstract;

/**
 * Interface Enwikuna_Helper_Enwikuna_Agency_Gateway_Interface
 *
 * @package Enwikuna\Enwikuna_Helper\Gateways\Interfaces
 */
interface Enwikuna_Helper_Enwikuna_Agency_Gateway_Interface {

	/**
	 * Enwikuna_Helper_Enwikuna_Agency_Gateway constructor
	 */
	public function __construct();

	/**
	 * Checks if the connection to Enwikuna Agency is successful and stable
	 *
	 * @return bool
	 */
	public function is_connected(): bool;

	/**
	 * Activates a product license
	 *
	 * @param Enwikuna_Helper_Product_Abstract $product
	 * @param string $license_key
	 *
	 * @return bool
	 */
	public function activate_license( Enwikuna_Helper_Product_Abstract $product, string $license_key ): bool;

	/**
	 * Deactivates a product license
	 *
	 * @param Enwikuna_Helper_Product_Abstract $product
	 *
	 * @return bool
	 */
	public function deactivate_license( Enwikuna_Helper_Product_Abstract $product ): bool;

	/**
	 * Returns info about the license
	 *
	 * @param Enwikuna_Helper_Product_Abstract $product
	 *
	 * @return false|object
	 */
	public function license_info( Enwikuna_Helper_Product_Abstract $product );

	/**
	 * Returns the latest update including the version for a product
	 *
	 * @param Enwikuna_Helper_Product_Abstract $product
	 *
	 * @return false|object
	 */
	public function update_info( Enwikuna_Helper_Product_Abstract $product );
}
