<?php

namespace Enwikuna\Enwikuna_Helper\Interfaces;

defined( 'ABSPATH' ) || exit;

/**
 * Interface Enwikuna_Helper_Encryptor_Interface
 *
 * @package Enwikuna\Enwikuna_Helper\Interfaces
 */
interface Enwikuna_Helper_Encryptor_Interface {

	/**
	 * Maybe encrypt data
	 *
	 * @param string|null $value
	 *
	 * @return string|null
	 */
	public function maybe_encrypt( ?string $value ): ?string;

	/**
	 * Maybe decrypt data
	 *
	 * @param string|null $value
	 *
	 * @return string|null
	 */
	public function maybe_decrypt( ?string $value ): ?string;

	/**
	 * Checks if the encryptor is configured
	 *
	 * @return bool
	 */
	public function is_configured(): bool;

	/**
	 * Returns a random encryptor key
	 *
	 * @param bool $for_config
	 *
	 * @return false|string
	 */
	public function get_random_key( bool $for_config = false );

	/**
	 * Checks if auto insert/delete of encryptor key within wp-config.php is possible or not
	 *
	 * @return bool
	 */
	public function supports_auto_insert_delete(): bool;

	/**
	 * Inserts the encryptor key into the wp-config.php
	 */
	public function auto_insert_key(): bool;

	/**
	 * Deletes the encryptor key from the wp-config.php
	 *
	 * @return bool
	 */
	public function auto_delete_key(): bool;
}
