<?php

defined( 'ABSPATH' ) || exit;

global $current_tab;

/**
 * This filter filters the admin support tabs array
 *
 * @param array $tabs Includes the supports tabs
 *
 * @wp-hook ewkh_admin_support_tabs_array
 * @since 2.0.0
 */
$tabs              = apply_filters( 'ewkh_admin_support_tabs_array', array() ); // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
$tab_exists        = isset( $tabs[ $current_tab ] ) || has_action( 'ewkh_admin_support_' . $current_tab ) || has_action( 'ewkh_admin_support_tabs_' . $current_tab );
$current_tab_label = $tabs[ $current_tab ] ?? '';

if ( ! $tab_exists ) {
	wp_safe_redirect( admin_url( 'index.php?page=enwikuna' ) );
	exit;
}
?>
<div class="wrap enwikuna-helper">
	<h1 class="wp-heading-inline"><?php esc_html_e( 'Enwikuna Support', 'enwikuna-helper' ); ?></h1>
	<hr class="wp-header-end">
	<?php
	/**
	 * This hook fires before the support output
	 *
	 * @wp-hook ewkh_admin_before_support_{current_tab}
	 * @since 2.0.0
	 */
	do_action( 'ewkh_admin_before_support_' . $current_tab );
	?>
	<div class="enwikuna-helper-page-content">
		<nav class="nav-tab-wrapper">
			<?php
			foreach ( $tabs as $slug => $label ) {
				echo '<a href="' . esc_html( admin_url( 'tools.php?page=enwikuna-support&tab=' . esc_attr( $slug ) ) ) . '" class="nav-tab ' . ( $current_tab === $slug ? 'nav-tab-active' : '' ) . '">' . esc_html( $label ) . '</a>';
			}

			/**
			 * This hook fires during the support tabs output
			 *
			 * @wp-hook ewkh_admin_support_tabs
			 * @since 1.2.3
			 */
			do_action( 'ewkh_admin_support_tabs' );
			?>
		</nav>
		<h3><?php echo esc_html( $current_tab_label ); ?></h3>
		<?php
		/**
		 * This hook fires during the support content output
		 *
		 * @wp-hook ewkh_admin_support_{current_tab}
		 * @since 1.2.3
		 */
		do_action( 'ewkh_admin_support_' . $current_tab );
		?>
		<?php
		/**
		 * This hook fires after the support output
		 *
		 * @wp-hook ewkh_admin_after_support_{current_tab}
		 * @since 1.2.3
		 */
		do_action( 'ewkh_admin_after_support_' . $current_tab );
		?>
	</div>
</div>
