<?php

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Enwikuna\Enwikuna_Helper\Admin\Support\Modules\Enwikuna_Helper_Admin_Support_Debugger;

$supports_auto_insert_enable_disable = Enwikuna_Helper_Admin_Support_Debugger::get_instance()->supports_auto_insert_enable_disable();
$log                                 = Enwikuna_Helper_Admin_Support_Debugger::get_instance()->get_log();

if ( Constants::get_constant( 'WP_DEBUG' ) && Constants::get_constant( 'WP_DEBUG_LOG' ) ) {
	$action   = 'disable-debug-logging'; // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
	$btn_text = esc_html__( 'Disable debug logging', 'enwikuna-helper' );
} else {
	$action   = 'enable-debug-logging'; // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
	$btn_text = esc_html__( 'Enable debug logging', 'enwikuna-helper' );
}

$enable_disable_debug_logging_url = wp_nonce_url(
	add_query_arg(
		array(
			'action' => $action,
		),
		admin_url( 'tools.php?page=enwikuna-support&tab=debugger' )
	),
	'enwikuna-helper-' . $action,
	'enwikuna-helper-' . $action . '-nonce'
);

$delete_debug_log_url = wp_nonce_url(
	add_query_arg(
		array(
			'action' => 'delete-debug-log',
		),
		admin_url( 'tools.php?page=enwikuna-support&tab=debugger' )
	),
	'enwikuna-helper-delete-debug-log',
	'enwikuna-helper-delete-debug-log-nonce'
);
?>
<div id="debugger-actions-wrapper">
	<a href="<?php echo esc_url( $enable_disable_debug_logging_url ); ?>" class="button button-primary" <?php echo disabled( ! $supports_auto_insert_enable_disable ); ?>><?php echo esc_html( $btn_text ); ?></a>
	<?php if ( ! empty( $log ) ) { ?>
		<a href="<?php echo esc_url( $delete_debug_log_url ); ?>" class="button button-secondary"><?php esc_html_e( 'Delete debug log', 'enwikuna-helper' ); ?></a>
	<?php } ?>
</div>
<?php if ( ! $supports_auto_insert_enable_disable ) { ?>
	<div class="notice enwikuna-helper-notice inline notice-error">
		<p><?php esc_html_e( 'Debug logging can\'t be enabled / disabled because the wp-config.php file is not writable.', 'enwikuna-helper' ); ?></p>
	</div>
<?php } ?>
<?php if ( ! empty( $log ) ) { ?>
	<div id="log-viewer">
		<?php
		echo '<pre>';

		foreach ( $log as $entry ) {
			echo esc_html( $entry );
		}

		echo '</pre>';
		?>
	</div>
<?php } else { ?>
	<div class="notice enwikuna-helper-notice inline notice-info">
		<p><?php esc_html_e( 'There is currently no debug log to view. Please enable debug logging or log out some content.', 'enwikuna-helper' ); ?></p>
	</div>
<?php } ?>
