<?php

defined( 'ABSPATH' ) || exit;

use Automattic\Jetpack\Constants;
use Enwikuna\Enwikuna_Helper\Admin\Enwikuna_Helper_Admin_Setup_Wizard;

$steps              = Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_steps();
$current_step_key   = Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_current_step_key();
$current_step_index = Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_current_step_index();
$current_step       = Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_step( $current_step_key );
$next_step_url      = Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_step_url( Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_next_step_key() );
$error_message      = Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_error_message();
$icon_url           = Constants::get_constant( 'ENWIKUNA_HELPER_ASSETS_URL' ) . 'images' . DIRECTORY_SEPARATOR . 'icons' . DIRECTORY_SEPARATOR . 'plugin-icon.svg';

set_current_screen();
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta name="viewport" content="width=device-width"/>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
	<title><?php esc_html_e( 'Enwikuna Helper Setup Wizard', 'enwikuna-helper' ); ?></title>
	<?php
	do_action( 'admin_enqueue_scripts' );
	wp_print_scripts( 'enwikuna-helper-admin-setup-wizard' );
	do_action( 'admin_print_styles' );
	do_action( 'admin_print_scripts' );
	do_action( 'admin_head' );
	?>
</head>
<body id="enwikuna-helper-admin-setup-wizard" class="wp-core-ui enwikuna-helper-admin-setup-wizard-step-<?php echo esc_attr( $current_step_key ); ?>">
<ul id="enwikuna-helper-admin-setup-wizard-steps">
	<?php
	foreach ( $steps as $step_key => $step ) {
		$step_url = Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_step_url( $step_key );
		?>
		<li class="step-item <?php echo $current_step_key === $step_key ? 'active' : ''; ?>">
			<a href="<?php echo esc_url( $step_url ); ?>"><span><?php echo esc_html( $step['name'] ); ?></span></a>
		</li>
	<?php } ?>
</ul>
<div id="enwikuna-helper-admin-setup-wizard-inner">
	<div id="enwikuna-helper-admin-setup-wizard-logo-wrapper">
		<div id="enwikuna-helper-admin-setup-wizard-logo">
			<img src="<?php echo esc_url( $icon_url ); ?>" alt="">
			<h1 class="no-border"><?php esc_html_e( 'Enwikuna Helper', 'enwikuna-helper' ); ?></h1>
		</div>
	</div>
	<form id="enwikuna-helper-admin-setup-wizard-form" method="post" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>">
		<div id="enwikuna-helper-admin-setup-wizard-content-wrapper">
			<?php if ( ! empty( $error_message ) ) { ?>
				<div id="error-message" class="notice notice-error">
					<p><?php echo wp_kses_post( $error_message ); ?></p>
				</div>
				<?php
			}

			if ( ! empty( $current_step['view'] ) ) {
				Enwikuna_Helper_Admin_Setup_Wizard::get_instance()->get_step_content( $current_step['view'] );
			}
			?>
		</div>
		<div id="enwikuna-helper-admin-setup-wizard-footer">
			<div id="enwikuna-helper-admin-setup-wizard-links">
				<input type="hidden" name="action" value="ewkh_admin_setup_wizard"/>
				<input type="hidden" name="step" value="<?php echo esc_attr( $current_step_key ); ?>"/>
				<?php
				wp_nonce_field( 'enwikuna-helper-admin-setup-wizard', 'enwikuna-helper-admin-setup-wizard-nonce' );

				if ( $current_step_index < count( $steps ) ) {
					$skip_step_url = wp_nonce_url(
						add_query_arg(
							array(
								'skip' => esc_attr( $current_step_key ),
							),
							$next_step_url
						),
						'enwikuna-helper-admin-setup-wizard-skip',
						'enwikuna-helper-admin-setup-wizard-skip-nonce'
					);
					?>
					<a id="skip-link" href="<?php echo esc_url( $skip_step_url ); ?>"><?php esc_html_e( 'Skip step', 'enwikuna-helper' ); ?></a>
					<?php
				}

				if ( isset( $current_step['button_next_link'] ) && ! empty( $current_step['button_next_link'] ) ) {
					?>
					<a class="button button-primary"
					   href="<?php echo esc_url( $current_step['button_next_link'] ); ?>"><?php echo isset( $current_step['button_next'] ) && ! empty( $current_step['button_next'] ) ? esc_attr( $current_step['button_next'] ) : esc_attr__( 'Continue', 'enwikuna-helper' ); ?></a>
				<?php } else { ?>
					<button class="button button-primary"
							type="submit"><?php echo isset( $current_step['button_next'] ) && ! empty( $current_step['button_next'] ) ? esc_attr( $current_step['button_next'] ) : esc_attr__( 'Continue', 'enwikuna-helper' ); ?></button>
				<?php } ?>
			</div>
			<div id="escape-link">
				<a href="<?php echo esc_url( admin_url() ); ?>"><?php esc_html_e( 'Return to WP Admin', 'enwikuna-helper' ); ?></a>
			</div>
		</div>
	</form>
</div>
<?php
do_action( 'admin_footer', '' );
do_action( 'admin_print_footer_scripts' );
?>
</body>
</html>

